# Synoku

Minimal placeholder package to reserve the name on PyPI.

## License

Synoku API is licensed under the Business Source License 1.1 (BUSL-1.1).  
See the [LICENSE](./LICENSE) file or visit [api.synoku.com/bsl11](https://api.synoku.com/bsl11/) for full terms.
